﻿////////////////////////////////////////////////////////////////////////////
// 
// Copyright (C) 2007 e-Channels CORPORATION
// 
// ALL RIGHTS RESERVED BY e-Channels CORPORATION, THIS PROGRAM
// MUST BE USED SOLELY FOR THE PURPOSE FOR WHICH IT WAS  
// FURNISHED BY e-Channels CORPORATION, NO PART OF THIS PROGRAM
// MAY BE REPRODUCED OR DISCLOSED TO OTHERS, IN ANY FORM
// WITHOUT THE PRIOR WRITTEN PERMISSION OF e-Channels CORPORATION.
// USE OF COPYRIGHT NOTICE DOES NOT EVIDENCE PUBLICATION
// OF THE PROGRAM
// 
//			e-Channels CONFIDENTIAL AND PROPRIETARY
// 
////////////////////////////////////////////////////////////////////////////
//
//	金额转换函数 zhanghao@yuchengtech.com
//
////////////////////////////////////////////////////////////////////////////

var Nums = new Array("零", "壹", "贰", "叁", "肆", "伍", "陆", "柒", "捌", "玖"); 
var Digits = new Array("", "拾", "佰", "仟"); 
var Units = new Array("", "万", "亿", "万亿","仟兆"); 

/**
* 检查字符串是否为合法的金额
* @param {String} 字符串
* @return {bool} 是否为合法金额
*/
function isMoney(s) 
{
	var isMoney = RegExp(/^[0-9]{0,12}\.[0-9]{0,2}$/);
	return ( isMoney.test(s) );
}

/**
* 判断输入变量是否是浮点数
* @param {String} 要检查的变量值
* @return {bool} 是否为浮点数
*/
function isFloat( s )
{
	var isFloat = RegExp(/^([0-9]+(\.+))[0-9]+$/);
	return ( isFloat.test(s) );
}

/**
* 检查指定的input中输入的金额是否合法，如果合法返回金额，否则返回null
* @param {String} 要检查的input的id
*/
function getMoney(inputName)
{
	var money = document.getElementById(inputName).value;
	if ( money !=null && money.length>0 )
	{
		return removeComma( money );
	}else{
		return "";
	}
}

/**
* 检查指定的input中输入的金额是否合法，并进行显示转换
* @param {String} 要检查的input的id
*/
function checkMoney(inputName)
{
	var input = document.getElementById(inputName);
	if ( isEmpty( input.value ) )
	{
		return false;
	}

	//处理类似状况如：输入时输入99.就失焦了
	var inputValue = input.value;
	var inputLength = (input.value).length;
	var point = inputValue.substr(inputLength-1,1);
	if(point == "."){
		input.value =  input.value+'00';
	}
	//处理结束
	var dotPos = input.value.indexOf(".");
	if ( dotPos < 0 )
	{
		input.value =  input.value+'.00';
	}
	var testMoney = removeComma( input.value );
	if ( isMoney( testMoney ) )
	{
		input.value = toCashWithCommaAndDot( testMoney );
		return true;
	}else{
		if( !isFloat( testMoney ) ){
			input.value = "";
			alert("金额输入有误");
			input.focus();
			return false;
		}
		input.value = "";
		alert("金额长度不能大于12位整数加2位小数");
		input.focus();
		return false;
	}
} 

/**
* 转换为中文金额表示
* @param {String} 要转换的金额字符串
* @return {String} 转换后的金额字符串
*/
//100,00.00
function toChineseCash( cash )
{
	if ( cash == null || cash.length == 0 )
	{
		return '';
	}
	var noCommaCash = removeComma(cash);
	if ( parseFloat(cash) == 0 )
	{
		return '';
	}
	if( !isFloat( noCommaCash ) )
	{
		return convertIntegerToChineseCash(noCommaCash);
	}	
	var dotIndex = noCommaCash.indexOf('.');
	var integerCash = noCommaCash.substring( 0, dotIndex );
	var decimalCash = noCommaCash.substring( dotIndex + 1 );
	return convertIntegerToChineseCash(integerCash)+convertDecimalToChineseCash(decimalCash);
}
//10000
function toChineseCashNoFloat( cash )
{
	if ( cash == null || cash.length == 0 )
	{
		return '';
	}
	var noCommaCash = cash;
	if ( parseFloat(cash) == 0 )
	{
		return '';
	}
	if( !isFloat( noCommaCash ) )
	{
		return convertIntegerToChineseCash(noCommaCash);
	}	
	var dotIndex = noCommaCash;
	var integerCash = noCommaCash.substring( 0, dotIndex );
	var decimalCash = noCommaCash.substring( dotIndex + 1 );
	return convertIntegerToChineseCash(integerCash)+convertDecimalToChineseCash(decimalCash);
}
/**
* 为金额添加,分割符
* @param {String} 要转换的金额字符串
* @return {String} 转换后的金额字符串
*/
function toCashWithComma( cash )
{
	while( cash.charAt(0) == '0' )
	{
		cash = cash.substr(1);
	}
	if( !isFloat( cash ) )
		return addComma(cash);	
			
	var dotIndex = cash.indexOf('.');
	var integerCash = cash.substring( 0, dotIndex );
	var decimalCash = cash.substring( dotIndex );
	
	return addComma(integerCash)+decimalCash;
}

/**
* 为金额添加,分割符和.分割符
* @param {String} 要转换的金额字符串
* @return {String} 转换后的金额字符串
*/
function toCashWithCommaAndDot( cash )
{
	if (cash == null || cash =='null' || cash==''){
		return '';
	}
	var temp = toCashWithComma( cash );
	if ( temp.length == 0 )
	{
		return "0.00";
	}
	var dotPos = temp.indexOf(".");
	if ( dotPos < 0 )
	{
		return temp+'.00';
	}
	if ( dotPos == 0 )
	{
		temp = '0' + temp;
		dotPos = temp.indexOf(".");
	}
	if ( dotPos == temp.length-2)
	{
		return temp + '0';
	}
	if ( dotPos == temp.length-1)
	{
		return temp + '00';
	}
	return temp;
}

function convertIntegerToChineseCash(cash)
{
	if ( cash == "0" )
		return "";
    var S = ""; //返回值 
    var p = 0; //字符位置指针 
    var m = cash.length % 4; //取模 

    // 四位一组得到组数 
    var k = (m > 0 ? Math.floor(cash.length / 4) + 1 : Math.floor(cash.length / 4)); 
    // 外层循环在所有组中循环 
    // 从左到右 高位到低位 四位一组 逐组处理 
    // 每组最后加上一个单位: "[万亿]","[亿]","[万]" 
    for (var i = k; i > 0; i--) 
    {
        var L = 4; 
        if (i == k && m != 0)
        {
            L = m;
        }
        // 得到一组四位数 最高位组有可能不足四位 
        var s = cash.substring(p, p + L);
        var l = s.length;

        // 内层循环在该组中的每一位数上循环 从左到右 高位到低位 
        for (var j = 0;j < l;j++)
        {
            var n = parseInt(s.substring(j, j+1));
            if (n == 0)
            {
                if ((j < l - 1) && (parseInt(s.substring(j + 1, j + 1+ 1)) > 0) //后一位(右低) 
                    && S.substring(S.length-1,S.length) != Nums[n])
                {
                    S += Nums[n];
                }
            }
            else 
            {
                S += Nums[n];
                S += Digits[l - j - 1];
            }
        }
        p += L;
        // 每组最后加上一个单位: [万],[亿] 等 
        if (i < k)//不是最高位的一组 
        {
            if (parseInt(s)!= 0)
            {
                //如果所有 4 位不全是 0 则加上单位 [万],[亿] 等 
                S += Units[i - 1];
            }
        }
        else
        {
            //处理最高位的一组,最后必须加上单位 
            S += Units[i - 1];
        }
    }
	//alert(S);
	return S+"元整";
}

function convertDecimalToChineseCash( cash )
{
	var returnCash = "";
	
	if ( cash == "00" )
		returnCash = "整";
	else
	{
		for( var i = 0;i < cash.length; i++ )
		{
			if( i >= 2 )
				break;
			var intValue = parseInt(cash.charAt(i));
		
			switch( i )
			{
				case 0:
					if ( intValue != 0 )
						returnCash += Nums[intValue]+"角";
					break;
				case 1:
					returnCash += Nums[intValue]+"分";
					break;
				default:
					break;
			}
		}
		
	}
	return returnCash;	
}

function addComma(str) {
	if (str.length > 3) 
	{
		var mod = str.length % 3;
		var output = (mod > 0 ? (str.substring(0,mod)) : '');
		for (i=0 ; i < Math.floor(str.length / 3); i++) {
			if ((mod == 0) && (i == 0))
				output += str.substring(mod+ 3 * i, mod + 3 * i + 3);
			else
				output += ',' + str.substring(mod + 3 * i, mod + 3 * i + 3);
		}
		return (output);
	}
	else return str;
}

function removeComma(str)
{
	return str.replace(new RegExp('\,',["g"]),'');
}

function ChinaCost(numberValue){
var numberValue=new String(Math.round(numberValue*100)); // 数字金额
var chineseValue=""; // 转换后的汉字金额
var String1 = "零壹贰叁肆伍陆柒捌玖"; // 汉字数字
var String2 = "万仟佰拾亿仟佰拾万仟佰拾元角分"; // 对应单位
var len=numberValue.length; // numberValue 的字符串长度
var Ch1; // 数字的汉语读法
var Ch2; // 数字位的汉字读法
var nZero=0; // 用来计算连续的零值的个数
var String3; // 指定位置的数值
if(len>15){
alert("超出计算范围");
return "";
}
if (numberValue==0){
chineseValue = "零元整";
return chineseValue;
}

String2 = String2.substr(String2.length-len, len); // 取出对应位数的STRING2的值
for(var i=0; i<len; i++){
String3 = parseInt(numberValue.substr(i, 1),10); // 取出需转换的某一位的值
if ( i != (len - 3) && i != (len - 7) && i != (len - 11) && i !=(len - 15) ){
if ( String3 == 0 ){
Ch1 = "";
Ch2 = "";
nZero = nZero + 1;
}
else if ( String3 != 0 && nZero != 0 ){
Ch1 = "零" + String1.substr(String3, 1);
Ch2 = String2.substr(i, 1);
nZero = 0;
}
else{
Ch1 = String1.substr(String3, 1);
Ch2 = String2.substr(i, 1);
nZero = 0;
}
}
else{ // 该位是万亿，亿，万，元位等关键位
if( String3 != 0 && nZero != 0 ){
Ch1 = "零" + String1.substr(String3, 1);
Ch2 = String2.substr(i, 1);
nZero = 0;
}
else if ( String3 != 0 && nZero == 0 ){
Ch1 = String1.substr(String3, 1);
Ch2 = String2.substr(i, 1);
nZero = 0;
}
else if( String3 == 0 && nZero >= 3 ){
Ch1 = "";
Ch2 = "";
nZero = nZero + 1;
}
else{
Ch1 = "";
Ch2 = String2.substr(i, 1);
nZero = nZero + 1;
}
if( i == (len - 11) || i == (len - 3)){ // 如果该位是亿位或元位，则必须写上
Ch2 = String2.substr(i, 1);
}
}
chineseValue = chineseValue + Ch1 + Ch2;
}

if ( String3 == 0 ){ // 最后一位（分）为0时，加上“整”
chineseValue = chineseValue + "整";
}

return chineseValue;
}